@@ -22,6 +22,8 @@
 
 #' Keep the curl handle in httr2 under the `handle` attribute of `request`
 #'
+#' @importFrom rlang !!! fn_fmls_syms new_function expr current_env base_env
+#' @importFrom rlang new_environment
 #' @noRd
 patch_httr2_keep_handle <- function() {
 
@@ -34,15 +36,26 @@ patch_httr2_keep_handle <- function() {
 
         if (is.null(attr(original, PATCHED))) {
 
-            patched <- function(req, path = NULL, handle = NULL) {
+            fmls_original <- formals(original)
 
-                if (!is.null(handle)) {
-                    attr(req, 'handle') <- handle
-                }
+            patched <- new_function(
+                args = fmls_original,
+                body = expr({
+                    if (!is.null(handle)) {
+                        attr(req, 'handle') <- handle
+                    }
+                    ORIGINAL(!!!fn_fmls_syms(original))
+                }),
+                env = new_environment(
+                    list(
+                        ORIGINAL = original,
+                        original_formals = fmls_original
+                    ),
+                    parent = base_env()
+                )
+            )
 
-                original(req, path = path, handle = handle)
-
-            }
+            environment(patched)$ORIGINAL <- original
 
             attr(patched, PATCHED) <- TRUE
 
